Groggy Theme Selector

# 🎨 Groggy Theme Comparison

Compare all available themes side by side to help with styling decisions.

Light

Name | Age | Score | Active
--- | --- | --- | ---
Alice | 25 | 91.50 | ✓
Bob | 30,000 | 87.00 | ✗

Dark

Name | Age | Score | Active
--- | --- | --- | ---
Alice | 25 | 91.50 | ✓
Bob | 30,000 | 87.00 | ✗

Minimal

Name | Age | Score | Active
--- | --- | --- | ---
Alice | 25 | 91.50 | ✓
Bob | 30,000 | 87.00 | ✗

Publication

Name | Age | Score | Active
--- | --- | --- | ---
Alice | 25 | 91.50 | ✓
Bob | 30,000 | 87.00 | ✗